==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/FindOfferingByIdResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for findOfferingByIdResponse complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="findOfferingByIdResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}serviceOffering" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "findOfferingByIdResponse", propOrder = {
    "_return"
})
public class FindOfferingByIdResponse {

    @XmlElement(name = "return")
    protected ServiceOffering _return;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link ServiceOffering }
     *     
     */
    public ServiceOffering getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link ServiceOffering }
     *     
     */
    public void setReturn(ServiceOffering value) {
        this._return = value;
    }

}

==> tv_9.2501-2601051638.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/pricing/FindOfferingByIdResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.pricing;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for findOfferingByIdResponse complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="findOfferingByIdResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}serviceOffering" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "findOfferingByIdResponse", propOrder = {
    "_return"
})
public class FindOfferingByIdResponse {

    @XmlElement(name = "return")
    protected ServiceOffering _return;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link ServiceOffering }
     *     
     */
    public ServiceOffering getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link ServiceOffering }
     *     
     */
    public void setReturn(ServiceOffering value) {
        this._return = value;
    }

}
